@@ -56,8 +56,13 @@ class Tag:
             self._attrs[prop] = value
         return self
 
-    def data(self, data: dict):
-        self._data.update(data)
+    def data(self, **kwargs):
+        for prop, value in kwargs.items():
+            result = []
+            for match in self.camel_reg.finditer(prop):
+                result.append(match.group(0))
+            prop = "-".join(result).lower()
+            self._data[prop] = value
         return self
 
     def add_child(self, x: Union[list, Union[str, 'Tag']]):
