@@ -77,7 +77,7 @@ class LabExtDataTable {
       },
       drawCallback: () => {
         if (this.isInitComplete) {
-          this.tunnel.send_msg(JSON.stringify({"type": "status", "msg": "redraw"}));
+          this.tunnel.send_msg(JSON.stringify({"type": "status", "msg": "redraw_done"}));
         }
       },
       ...this.options
